@@ -28,6 +28,7 @@
 #include <KAboutData>
 
 #include "aboutdata.h"
+#include <klocalizedstring.h>
 
 static int convertToNative( const QUrl &file, const QByteArray& outfile )
 {
@@ -55,6 +56,8 @@ int main(int argc, char **argv)
   QCoreApplication::setApplicationVersion( i18n( KIGVERSION ) );
   QCoreApplication::setOrganizationDomain( i18n( "kde.org" ) );
 
+  KLocalizedString::setApplicationDomain("kig");
+
   about.setupCommandLine( &parser );
   parser.addHelpOption();
   parser.addOption( convertToNativeOption );
