@@ -36,6 +36,7 @@
 #include <QRect>
 
 #include <KColorDialog>
+#include <KIconEngine>
 #include <KLocale>
 
 struct color_struct
@@ -83,8 +84,8 @@ void BuiltinObjectActionsProvider::fillUpMenu( NormalModePopupObjects& popup, in
       popup.addInternalAction( menu, i18n( "&Show" ), nextfree+1 );
     }
     nextfree += 2;
-    popup.addInternalAction( menu, KIcon( "transform-move", l ), i18n( "&Move" ), nextfree++ );
-    popup.addInternalAction( menu, KIcon( "edit-delete", l ), i18n( "&Delete" ), nextfree++ );
+    popup.addInternalAction( menu, QIcon( new KIconEngine( "transform-move", l ) ), i18n( "&Move" ), nextfree++ );
+    popup.addInternalAction( menu, QIcon( new KIconEngine( "edit-delete", l ) ), i18n( "&Delete" ), nextfree++ );
   }
   else if ( menu == NormalModePopupObjects::SetColorMenu )
   {
@@ -94,7 +95,7 @@ void BuiltinObjectActionsProvider::fillUpMenu( NormalModePopupObjects& popup, in
       p.fill( QColor( colors[i].color ) );
       popup.addInternalAction( menu, QIcon( p ), i18n( colors[i].name ), nextfree++ );
     }
-    popup.addInternalAction( menu, KIcon( "color", l ), i18n( "&Custom Color" ), nextfree++ );
+    popup.addInternalAction( menu, QIcon( new KIconEngine( "color", l ) ), i18n( "&Custom Color" ), nextfree++ );
   }
   else if ( menu == NormalModePopupObjects::SetSizeMenu && !popup.onlyLabels() )
   {
